@@ -42,6 +42,12 @@ class ActionList:
             "resetConcentrations",
             "resetParameters",
         ]
+        self.before_model = [
+            "setModelName",
+            "substanceUnits",
+            "version",
+            "setOption",
+        ]
         self.possible_types = (
             self.normal_types + self.no_setter_syntax + self.square_braces
         )
@@ -389,6 +395,11 @@ class ActionList:
         self.arg_dict["resetConcentrations"] = []
         self.arg_dict["resetParameters"] = []
 
+    def is_before_model(self, action_name):
+        if action_name in self.before_model:
+            return True
+        return False
+
 
 def find_BNG_path(BNGPATH=None):
     """
